```
Usage: vcd gateway configure-external-network remove [OPTIONS] <name>

Options:
  -e, --external-network <external network>
                                  external network that needs to be removed
                                  from the gateway.  [required]
  -h, --help                      Show this message and exit.

```
